package github.benjamin.equipreservebackend.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import github.benjamin.equipreservebackend.dto.LeaderApprovalDTO;
import github.benjamin.equipreservebackend.entity.Approval;
import github.benjamin.equipreservebackend.response.ResponseResult;
import github.benjamin.equipreservebackend.service.ApprovalService;
import github.benjamin.equipreservebackend.vo.LeaderApprovalVO;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/approval")
@RequiredArgsConstructor
public class ApprovalController {

    private final ApprovalService approvalService;

    @PreAuthorize("hasAnyRole('LEADER', 'DEVICE_ADMIN')")
    @PostMapping
    public ResponseResult<?> addApproval(@RequestBody LeaderApprovalDTO dto) {
        approvalService.addApproval(dto);
        return ResponseResult.success();
    }

    @PreAuthorize("hasAnyRole('LEADER', 'DEVICE_ADMIN')")
    @GetMapping("/{id}")
    public ResponseResult<IPage<LeaderApprovalVO>> getApproval(@PathVariable("id") Long id,
                                                                     @RequestParam(defaultValue = "1") Integer page,
                                                                     @RequestParam(defaultValue = "10") Integer size,
                                                                     @RequestParam(required = false) String applicantName,
                                                                     @RequestParam(required = false) String deviceName) {
        Page<Approval> pageRequest = new Page<>(page, size);
        return ResponseResult.success(approvalService.getApproval(pageRequest, id, applicantName, deviceName));
    }

}
